@@ -208,8 +208,17 @@ public class CompileAction extends Action {
             // note: in the following code, some args are overwritten in place
             String currArg = args.get(i);
 
+            boolean isSourceFile = false;
+
             if (currArg.endsWith(".java")) {
                 foundJavaFile = true;
+                isSourceFile = true;
+            } else if (currArg.endsWith(".jasm") || currArg.endsWith(".jcod")) {
+                foundAsmFile = true;
+                isSourceFile = true;
+            }
+
+            if (isSourceFile) {
                 File sourceFile = new File(currArg.replace('/', File.separatorChar));
                 if (!sourceFile.isAbsolute()) {
                     // User must have used @compile, so file must be
@@ -221,22 +230,6 @@ public class CompileAction extends Action {
                         throw new ParseException(CANT_FIND_SRC + currArg);
                     args.set(i, absSourceFile.toString());
                 }
-            } else if (currArg.endsWith(".jasm") || currArg.endsWith("jcod")) {
-                if (module != null) {
-                    throw new ParseException(COMPILE_OPT_DISALLOW);
-                }
-                foundAsmFile = true;
-                File sourceFile = new File(currArg.replace('/', File.separatorChar));
-                if (!sourceFile.isAbsolute()) {
-                    // User must have used @compile, so file must be
-                    // in the same directory as the defining file.
-                    if (multiModule)
-                        addModule(currArg);
-                    Path absSourceFile = locations.absTestSrcFile(null, sourceFile);
-                    if (!Files.exists(absSourceFile))
-                        throw new ParseException(CANT_FIND_SRC + currArg);
-                    args.set(i, absSourceFile.toString());
-                }
             }
 
             if (currArg.equals("-classpath") || currArg.equals("-cp")
@@ -363,11 +356,7 @@ public class CompileAction extends Action {
             }
         }
 
-        if (runJavac
-                && !script.disablePreview()
-                && !seenEnablePreview
-                && (script.enablePreview())
-                && (libLocn == null || libLocn.isTest())) {
+        if (runJavac && script.enablePreview() && !seenEnablePreview) {
             String version = script.getTestJDKVersion().name();
             // always prepend in order to not mess with variadic arguments
             if (!seenSourceOrRelease) {
@@ -734,8 +723,12 @@ public class CompileAction extends Action {
                     timeoutHandler,
                     section);
         } catch (Agent.ActionTimeout te) {
-            final String msg = "\"" + getName() + "\" action timed out with a timeout of "
+            String msg = "\"" + getName() + "\" action timed out with a timeout of "
                     + timeout + " seconds on agent " + agent.id;
+            if (te.getSuppressedStatus().isPresent()) {
+                Status suppressed = te.getSuppressedStatus().get();
+                msg += "; but completed after timeout - suppressed status: \"" + suppressed + "\"";
+            }
             status = error(msg);
         } catch (Agent.Fault e) {
             if (e.getCause() instanceof IOException)
